summaryrefslogtreecommitdiffstats
path: root/certmanager/lib/ui/adddirectoryservicedialogimpl.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'certmanager/lib/ui/adddirectoryservicedialogimpl.cpp')
-rw-r--r--certmanager/lib/ui/adddirectoryservicedialogimpl.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/certmanager/lib/ui/adddirectoryservicedialogimpl.cpp b/certmanager/lib/ui/adddirectoryservicedialogimpl.cpp
index 7567be710..a6210cabe 100644
--- a/certmanager/lib/ui/adddirectoryservicedialogimpl.cpp
+++ b/certmanager/lib/ui/adddirectoryservicedialogimpl.cpp
@@ -20,11 +20,11 @@
In addition, as a special exception, the copyright holders give
permission to link the code of this program with any edition of
- the Qt library by Trolltech AS, Norway (or with modified versions
- of Qt that use the same license as Qt), and distribute linked
+ the TQt library by Trolltech AS, Norway (or with modified versions
+ of TQt that use the same license as TQt), and distribute linked
combinations including the two. You must obey the GNU General
Public License in all respects for all of the code used other than
- Qt. If you modify this file, you may extend this exception to
+ TQt. If you modify this file, you may extend this exception to
your version of the file, but you are not obligated to do so. If
you do not wish to do so, delete this exception statement from
your version.
@@ -40,14 +40,14 @@
#include <klineedit.h>
/*
* Constructs a AddDirectoryServiceDialogImpl which is a child of 'parent', with the
* name 'name' and widget flags set to 'f'
*
* The dialog will by default be modeless, unless you set 'modal' to
* TRUE to construct a modal dialog.
*/
-AddDirectoryServiceDialogImpl::AddDirectoryServiceDialogImpl( TQWidget* parent, const char* name, bool modal, WFlags fl )
- : AddDirectoryServiceDialog( parent, name, modal, fl )
+AddDirectoryServiceDialogImpl::AddDirectoryServiceDialogImpl( TQWidget* tqparent, const char* name, bool modal, WFlags fl )
+ : AddDirectoryServiceDialog( tqparent, name, modal, fl )
{
portED->setValidator( new TQIntValidator( 0, 65535, portED ) );
}
@@ -57,7 +57,7 @@ AddDirectoryServiceDialogImpl::AddDirectoryServiceDialogImpl( TQWidget* parent,
*/
AddDirectoryServiceDialogImpl::~AddDirectoryServiceDialogImpl()
{
// no need to delete child widgets, Qt does it all for us
}
#include "adddirectoryservicedialogimpl.moc"
@@ -40,14 +40,14 @@
#include <klineedit.h>
/*
- * Constructs a AddDirectoryServiceDialogImpl which is a child of 'parent', with the
+ * Constructs a AddDirectoryServiceDialogImpl which is a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'
*
@@ -57,7 +57,7 @@ AddDirectoryServiceDialogImpl::AddDirectoryServiceDialogImpl( TQWidget* parent,
AddDirectoryServiceDialogImpl::~AddDirectoryServiceDialogImpl()
{
- // no need to delete child widgets, Qt does it all for us
+ // no need to delete child widgets, TQt does it all for us
}
#include "adddirectoryservicedialogimpl.moc"